# mescrappy - Python + Selenium **Youtube** scrapper

<!-- PROJECT LOGO -->
<br />
<p align="center">
  <a href="https://github.com/MerlinEmris/youtube_srapping_with_python">
    <img src="images/logo.png" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center"> Youtube Srapping With Python (Selenium)</h3>

  <!-- <p align="center">
    project_description
    <br />
    <a href="https://github.com/MerlinEmris/youtube_srapping_with_python"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/MerlinEmris/youtube_srapping_with_python">View Demo</a>
    ·
    <a href="https://github.com/MerlinEmris/youtube_srapping_with_python/issues">Report Bug</a>
    ·
    <a href="https://github.com/MerlinEmris/youtube_srapping_with_python/issues">Request Feature</a>
  </p> -->
</p>

<!-- TABLE OF CONTENTS -->

<details open="open">
  <summary><h2 style="display: inline-block">Table of Contents</h2></summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
    <li><a href="#acknowledgements">Acknowledgements</a></li>
  </ol>
</details>

<!-- ABOUT THE PROJECT -->

## About The Project

<!-- [![Product Name Screen Shot][product-screenshot]](https://example.com) -->

<!-- `merlinemris`, `youtube_srapping_with_python`, `@merlinemris96`, `merdanchariyarov@gmail.com`, `mescrap`, `Youtube video data scrapper` -->

### Built With

- [python3]()
- [selenium]()
<!-- GETTING STARTED -->

## Getting Started

### Installation

1. To use this package first install it: [package](https://test.pypi.org/project/mescrappy)

`pip install mescrappy`

2. import srapper to your project

`from mescrappy.srappy import scrapper`
`scrapper.youtube_video_data_scrapper(url='', driver='')`

## Usage

You can use this package to scrap youtube video's:

1. title
2. view count
3. description
4. like
5. dislike
6. post date
7. owner

<!-- ROADMAP -->

## Roadmap

See the [open issues](https://github.com/MerlinEmris/youtube_srapping_with_python/issues) for a list of proposed features (and known issues).

<!-- CONTRIBUTING -->

<!-- LICENSE -->

## License

Distributed under the MIT License. See `LICENSE` for more information.

<!-- CONTACT -->

## Contact

Merdan Chariyarov - [@merlinemris96](https://twitter.com/merlinemris96) - merdanchariyarov@gmail.com

Project Link: [https://github.com/MerlinEmris/youtube_srapping_with_python](https://github.com/MerlinEmris/youtube_srapping_with_python)

<!-- ACKNOWLEDGEMENTS -->

## Acknowledgements

- [https://towardsdatascience.com/how-to-package-your-python-code-df5a7739ab2e](https://towardsdatascience.com/how-to-package-your-python-code-df5a7739ab2e)
